{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "remove lower scoring overlaps from cmsearch --tblout files.",
            "doc": "https://github.com/nawrockie/cmsearch_tblout_deoverlap/blob/master/00README.txt",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://github.com/nawrockie/cmsearch_tblout_deoverlap"
                            ],
                            "package": "cmsearch_tblout_deoverlap"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "C",
                            "envName": "LC_ALL"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "listing": [
                        "$(inputs.cmsearch_matches)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "clan information on the models provided",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--clanin"
                    },
                    "doc": "Not all models provided need to be a member of a clan",
                    "id": "#cmsearch-deoverlap.cwl/clan_information"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "id": "#cmsearch-deoverlap.cwl/cmsearch_matches"
                }
            ],
            "baseCommand": "cmsearch-deoverlap.pl",
            "id": "#cmsearch-deoverlap.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.deoverlapped"
                    },
                    "id": "#cmsearch-deoverlap.cwl/deoverlapped_matches"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                }
            ],
            "baseCommand": "cat",
            "stdout": "result",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    },
                    "id": "#concatenate.cwl/result"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search sequence(s) against a covariance model database",
            "doc": "http://eddylab.org/infernal/Userguide.pdf",
            "requirements": [
                {
                    "ramMin": 10240,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#infernal-cmsearch.cwl/covariance_model_database"
                },
                {
                    "label": "use CM's GA gathering cutoffs as reporting thresholds",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--cut_ga"
                    },
                    "id": "#infernal-cmsearch.cwl/cut_ga"
                },
                {
                    "label": "Omit the alignment section from the main output.",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--noali"
                    },
                    "doc": "This can greatly reduce the output volume.",
                    "id": "#infernal-cmsearch.cwl/omit_alignment_section"
                },
                {
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--hmmonly"
                    },
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold).  Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output. \n",
                    "id": "#infernal-cmsearch.cwl/only_hmm"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929"
                    ],
                    "id": "#infernal-cmsearch.cwl/query_sequences"
                },
                {
                    "type": "int",
                    "label": "search space size in *Mb* to <x> for E-value calculations",
                    "inputBinding": {
                        "prefix": "-Z"
                    },
                    "id": "#infernal-cmsearch.cwl/search_space_size"
                }
            ],
            "baseCommand": "cmsearch",
            "arguments": [
                {
                    "valueFrom": "matches.tbl",
                    "prefix": "--tblout"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "matches.tbl"
                    },
                    "id": "#infernal-cmsearch.cwl/matches"
                }
            ],
            "id": "#infernal-cmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#main/query_sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/remove_overlaps/deoverlapped_matches",
                    "id": "#main/matches"
                }
            ],
            "steps": [
                {
                    "run": "#infernal-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#main/covariance_models",
                            "id": "#main/cmsearch/covariance_model_database"
                        },
                        {
                            "default": true,
                            "id": "#main/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#main/cmsearch/only_hmm"
                        },
                        {
                            "source": "#main/query_sequences",
                            "id": "#main/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#main/cmsearch/search_space_size"
                        }
                    ],
                    "out": [
                        "#main/cmsearch/matches"
                    ],
                    "scatter": "#main/cmsearch/covariance_model_database",
                    "id": "#main/cmsearch"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/cmsearch/matches",
                            "id": "#main/concatenate_matches/files"
                        }
                    ],
                    "out": [
                        "#main/concatenate_matches/result"
                    ],
                    "id": "#main/concatenate_matches"
                },
                {
                    "run": "#cmsearch-deoverlap.cwl",
                    "in": [
                        {
                            "source": "#main/clan_info",
                            "id": "#main/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#main/concatenate_matches/result",
                            "id": "#main/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "out": [
                        "#main/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#main/remove_overlaps"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ]
}
